wlanutilities/wlanwizard/tsrc/stubs/wlanqtutils_stub.cpp
changeset 58 301aeb18ae47
parent 56 de27cc8389dd
--- a/wlanutilities/wlanwizard/tsrc/stubs/wlanqtutils_stub.cpp	Thu Sep 02 21:36:44 2010 +0300
+++ b/wlanutilities/wlanwizard/tsrc/stubs/wlanqtutils_stub.cpp	Fri Sep 17 08:35:49 2010 +0300
@@ -1,18 +1,19 @@
 /*
  * Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
  * All rights reserved.
  * This component and the accompanying materials are made available
  * under the terms of "Eclipse Public License v1.0"
  * which accompanies this distribution, and is available
  * at the URL "http://www.eclipse.org/legal/epl-v10.html".
  *
  * Initial Contributors:
  * Nokia Corporation - initial contribution.
  *
  * Contributors:
  *
  * Description:
  */
 
 #include "wlanqtutilsap.h"
 #include "wlanqtutils.h"
@@ -100,6 +101,12 @@
     QCOMPARE(iapId, mActiveWlanIapReturn);
 }
 
+void WlanQtUtils::moveIapToInternetSnap(int iapId)
+{
+    qDebug("moveIapToInternetSnap iapId = %d", iapId);
+    //mCalledMethods.append("moveIapToInternetSnap");
+}
+
 int WlanQtUtils::activeIap()
 {
     mCalledMethods.append("activeIap");
@@ -1,18 +1,19 @@
 /*
- * Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
- * All rights reserved.
- * This component and the accompanying materials are made available
- * under the terms of "Eclipse Public License v1.0"
- * which accompanies this distribution, and is available
- * at the URL "http://www.eclipse.org/legal/epl-v10.html".
- *
- * Initial Contributors:
- * Nokia Corporation - initial contribution.
- *
- * Contributors:
- *
- * Description:
- */
+* Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0"
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+* WLAN Qt Utilities library test stub.
+*/
 
 #include "wlanqtutilsap.h"